summaryrefslogtreecommitdiffstats
path: root/api/src/glfs-handles.h
diff options
context:
space:
mode:
authorJiffin Tony Thottan <jthottan@redhat.com>2016-06-10 18:23:43 +0530
committerJeff Darcy <jdarcy@redhat.com>2016-06-10 14:09:32 -0700
commit2775dc64101ed37c8d9809bf9852dbf0746ee2b6 (patch)
tree99aa09e79384cd5f8ff8f5a50667f6aa2f9f1f9d /api/src/glfs-handles.h
parent3474aa85e399a92d3ee9159a2d066d4bd73611a0 (diff)
libgfapi/upcall : prepend "glfs_" to callback_arg, callback_inode_arg
Change-Id: I371525775db4f6a4d69beb94baaa53d17b16fb41 BUG: 1344714 Signed-off-by: Jiffin Tony Thottan <jthottan@redhat.com> Reviewed-on: http://review.gluster.org/14702 CentOS-regression: Gluster Build System <jenkins@build.gluster.com> NetBSD-regression: NetBSD Build System <jenkins@build.gluster.org> Reviewed-by: Jeff Darcy <jdarcy@redhat.com> Tested-by: Jeff Darcy <jdarcy@redhat.com> Smoke: Gluster Build System <jenkins@build.gluster.com>
Diffstat (limited to 'api/src/glfs-handles.h')
-rw-r--r--api/src/glfs-handles.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/api/src/glfs-handles.h b/api/src/glfs-handles.h
index 6446cc30c7d..557934503d2 100644
--- a/api/src/glfs-handles.h
+++ b/api/src/glfs-handles.h
@@ -110,7 +110,7 @@ typedef struct glfs_object glfs_object_t;
*
* Currently supported upcall_events -
* GFAPI_INODE_INVALIDATE -
- * 'event_arg' - callback_inode_arg
+ * 'event_arg' - glfs_callback_inode_arg
*
* After processing the event, applications need to free 'event_arg'.
*
@@ -118,7 +118,7 @@ typedef struct glfs_object glfs_object_t;
* before calling glfs_fini(..). Hence making an assumption that
* 'fs' & ctx structures cannot be freed while in this routine.
*/
-struct callback_arg {
+struct glfs_callback_arg {
struct glfs *fs; /* glfs object */
int reason; /* Upcall event type */
void *event_arg; /* changes based in the event type */
@@ -128,7 +128,7 @@ struct callback_arg {
* After processing upcall event, they need to free "object" , "p_object",
* "oldp_object" using glfs_h_close(..).
*/
-struct callback_inode_arg {
+struct glfs_callback_inode_arg {
struct glfs_object *object; /* Object which need to be acted upon */
int flags; /* Cache UPDATE/INVALIDATE flags */
struct stat buf; /* Latest stat of this entry */
@@ -144,7 +144,7 @@ struct callback_inode_arg {
* dir handle */
};
/* reason list in callback_arg */
enum gfapi_callback_type {
GFAPI_CBK_EVENT_NULL,
GFAPI_INODE_INVALIDATE, /* invalidate cache entry */
@@ -273,7 +273,7 @@ glfs_h_access (struct glfs *fs, struct glfs_object *object, int mask) __THROW
This API is used to poll for upcall events stored in the
upcall list. Current users of this API is NFS-Ganesha.
Incase of any event received, it will be mapped appropriately
- into 'callback_arg' along with the handle('glfs_object') to be
+ into 'glfs_callback_arg' along with the handle('glfs_object') to be
passed to NFS-Ganesha.
In case of success, applications need to check the value of
@@ -297,7 +297,7 @@ glfs_h_access (struct glfs *fs, struct glfs_object *object, int mask) __THROW
*/
int
-glfs_h_poll_upcall (struct glfs *fs, struct callback_arg *cbk) __THROW
+glfs_h_poll_upcall (struct glfs *fs, struct glfs_callback_arg *cbk) __THROW
GFAPI_PUBLIC(glfs_h_poll_upcall, 3.7.0);
int
@@ -144,7 +144,7 @@ struct callback_inode_arg {
* dir handle */
};
-/* reason list in callback_arg */
+/* reason list in glfs_callback_arg */
enum gfapi_callback_type {
GFAPI_CBK_EVENT_NULL,